__author__ = "Sig Janoska-Bedi"
__copyright__ = "Copyright (c) 2020 Signe Janoska-Bedi"
__credits__ = ["Sig Janoska-Bedi",]
__license__ = "MIT"
__maintainer__ = "Sig Janoska-Bedi"
__email__ = "signe@siftingwinnowing.com"
__status__ = "Development"